"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const docker_command_1 = tslib_1.__importDefault(require("../../docker-command"));
const version_1 = tslib_1.__importDefault(require("../../version"));
const status_1 = tslib_1.__importDefault(require("./status"));
class Start extends docker_command_1.default {
    async run() {
        const { flags } = this.parse(Start);
        const status = await status_1.default.run(['--name', flags.name]);
        if (status === 0 /* STARTED */) {
            return false;
        }
        this.spinner.start('MESG Engine');
        const eventPromise = this.waitForEvent(({ Action, Type, from }) => Type === 'container' &&
            Action === 'start' &&
            from === `mesg/engine:${flags.version}`);
        this.spinner.status = 'Creating network';
        const network = await this.getOrCreateNetwork({ name: flags.name });
        this.spinner.status = 'Creating service';
        await this.createService(network, {
            name: flags.name,
            version: flags.version,
            colors: flags['log-force-colors'],
            format: flags['log-format'],
            level: flags['log-level']
        });
        this.spinner.status = 'Waiting service to start';
        await eventPromise;
        this.spinner.stop('Started');
        return true;
    }
}
Start.description = 'Start the MESG Engine\'s daemon';
Start.flags = Object.assign({}, docker_command_1.default.flags, { version: command_1.flags.string({
        description: 'Version of the engine to run',
        required: true,
        default: version_1.default.engine
    }), 'log-force-colors': command_1.flags.boolean({
        description: 'log force colors',
        default: false
    }), 'log-format': command_1.flags.enum({
        description: 'log format',
        default: 'text',
        options: ['text', 'json']
    }), 'log-level': command_1.flags.enum({
        description: 'log level',
        default: 'info',
        options: ['debug', 'info', 'warn', 'error', 'fatal', 'panic']
    }) });
exports.default = Start;
