"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const api_1 = require("mesg-js/lib/api");
const node_docker_api_1 = require("node-docker-api");
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const docker_1 = require("../../utils/docker");
class ServiceLogs extends root_command_1.default {
    constructor() {
        super(...arguments);
        this.docker = new node_docker_api_1.Docker(null);
    }
    async run() {
        const { args, flags } = this.parse(ServiceLogs);
        const dockerServices = await this.docker.service.list({
            filters: {
                label: [`mesg.hash=${args.INSTANCE_HASH}`]
            }
        });
        for (const service of dockerServices) {
            const logs = await service.logs({
                stderr: true,
                stdout: true,
                follow: flags.follow,
                tail: flags.tail && flags.tail >= 0 ? flags.tail : 'all'
            });
            logs
                .on('data', (buffer) => docker_1.parseLog(buffer).forEach(x => this.log(x)))
                .on('error', (error) => { throw error; });
        }
        if (flags.results) {
            this.api.execution.stream({
                filter: {
                    instanceHash: args.INSTANCE_HASH,
                    statuses: [
                        api_1.ExecutionStatus.COMPLETED,
                        api_1.ExecutionStatus.FAILED,
                    ],
                    taskKey: flags.task
                }
            })
                .on('data', data => this.log(this.formatResult(data)))
                .on('error', (error) => { throw error; });
        }
        if (flags.events) {
            this.api.event.stream({
                filter: {
                    instanceHash: args.INSTANCE_HASH,
                    key: flags.event,
                }
            })
                .on('data', (data) => this.log(this.formatEvent(data)))
                .on('error', (error) => { throw error; });
        }
        // return stream
    }
    formatEvent(event) {
        return `EVENT[${event.key}]: ` + chalk_1.default.gray(event.data);
    }
    formatResult(execution) {
        if (execution.error) {
            return `RESULT[${execution.taskKey}]: ` + chalk_1.default.red('ERROR:', execution.error);
        }
        return `RESULT[${execution.taskKey}]: ` + chalk_1.default.gray(execution.outputs || '');
    }
}
ServiceLogs.description = 'Show logs of a service';
ServiceLogs.flags = Object.assign({}, root_command_1.default.flags, { 
    // dependency: flags.string({
    //   char: 'd',
    //   description: 'Name of the dependency to show the logs from',
    //   multiple: true
    // }),
    events: command_1.flags.boolean({
        description: 'Don\'t display events',
        allowNo: true,
        default: true
    }), results: command_1.flags.boolean({
        description: 'Don\'t display results',
        allowNo: true,
        default: true
    }), event: command_1.flags.string({
        description: 'Only display a specific event'
    }), task: command_1.flags.string({
        description: 'Only display a specific task results'
    }), tail: command_1.flags.integer({
        description: 'Output only specified number of lines',
        default: -1
    }), follow: command_1.flags.boolean({
        description: 'Continuously display logs',
        allowNo: true,
        default: true
    }) });
ServiceLogs.args = [{
        name: 'INSTANCE_HASH',
        required: true,
    }];
exports.default = ServiceLogs;
